@@ -636,10 +636,15 @@ ags_window_load_add_menu_ladspa(AgsWindow *window,
   ladspa_manager_mutex = AGS_LADSPA_MANAGER_GET_OBJ_MUTEX(ladspa_manager);
 
   /* ladspa sub-menu */
-  ladspa_menu = g_menu_new();
   ladspa_item = g_menu_item_new("LADSPA",
 				NULL);
+  g_menu_append_item(menu,
+		     ladspa_item);
   
+  ladspa_menu = g_menu_new();  
+  g_menu_item_set_submenu(ladspa_item,
+			  G_MENU_MODEL(ladspa_menu));  
+
   /* get plugin */
   g_rec_mutex_lock(ladspa_manager_mutex);
   
@@ -659,6 +664,9 @@ ags_window_load_add_menu_ladspa(AgsWindow *window,
     GVariantBuilder *builder;
 
     gchar *filename, *effect;
+
+    filename = NULL;
+    effect = NULL;
     
     /* get filename and effect */
     g_object_get(list->data,
@@ -669,7 +677,7 @@ ags_window_load_add_menu_ladspa(AgsWindow *window,
     item = g_menu_item_new(effect,
 			   "app.add_ladspa_bridge");
 
-    builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+    builder = g_variant_builder_new(g_variant_type_new("as"));
     
     g_variant_builder_add(builder, "s", filename);
     g_variant_builder_add(builder, "s", effect);
@@ -686,12 +694,6 @@ ags_window_load_add_menu_ladspa(AgsWindow *window,
     /* iterate */
     list = list->next;
   }
-  
-  g_menu_item_set_submenu(ladspa_item,
-			  G_MENU_MODEL(ladspa_menu));  
-
-  g_menu_append_item(menu,
-		     ladspa_item);
 
   g_list_free_full(start_list,
 		   (GDestroyNotify) g_object_unref);
@@ -726,9 +728,14 @@ ags_window_load_add_menu_dssi(AgsWindow *window,
   dssi_manager_mutex = AGS_DSSI_MANAGER_GET_OBJ_MUTEX(dssi_manager);
 
   /* dssi sub-menu */
-  dssi_menu = g_menu_new();
   dssi_item = g_menu_item_new("DSSI",
 			      NULL);
+  g_menu_append_item(menu,
+		     dssi_item);
+
+  dssi_menu = g_menu_new();
+  g_menu_item_set_submenu(dssi_item,
+			  G_MENU_MODEL(dssi_menu));
 
   /* get plugin */
   g_rec_mutex_lock(dssi_manager_mutex);
@@ -759,7 +766,7 @@ ags_window_load_add_menu_dssi(AgsWindow *window,
     item = g_menu_item_new(effect,
 			   "app.add_dssi_bridge");
 
-    builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+    builder = g_variant_builder_new(g_variant_type_new("as"));
     
     g_variant_builder_add(builder, "s", filename);
     g_variant_builder_add(builder, "s", effect);
@@ -777,12 +784,6 @@ ags_window_load_add_menu_dssi(AgsWindow *window,
     list = list->next;
   }
 
-  g_menu_item_set_submenu(dssi_item,
-			  G_MENU_MODEL(dssi_menu));  
-
-  g_menu_append_item(menu,
-		     dssi_item);
-
   g_list_free_full(start_list,
 		   (GDestroyNotify) g_object_unref);
 }
@@ -817,9 +818,14 @@ ags_window_load_add_menu_lv2(AgsWindow *window,
   lv2_manager_mutex = AGS_LV2_MANAGER_GET_OBJ_MUTEX(lv2_manager);
 
   /* lv2 sub-menu */
-  lv2_menu = g_menu_new();
   lv2_item = g_menu_item_new("LV2",
-			      NULL);
+			      NULL);  
+  g_menu_append_item(menu,
+		     lv2_item);
+
+  lv2_menu = g_menu_new();
+  g_menu_item_set_submenu(lv2_item,
+			  G_MENU_MODEL(lv2_menu));  
 
   /* get plugin */
   g_rec_mutex_lock(lv2_manager_mutex);
@@ -842,7 +848,7 @@ ags_window_load_add_menu_lv2(AgsWindow *window,
 	item = g_menu_item_new(effect,
 			       "app.add_lv2_bridge");
 
-	builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+	builder = g_variant_builder_new(g_variant_type_new("as"));
     
 	g_variant_builder_add(builder, "s", filename);
 	g_variant_builder_add(builder, "s", effect);
@@ -877,7 +883,7 @@ ags_window_load_add_menu_lv2(AgsWindow *window,
 	item = g_menu_item_new(effect,
 			       "app.add_lv2_bridge");
 
-	builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+	builder = g_variant_builder_new(g_variant_type_new("as"));
     
 	g_variant_builder_add(builder, "s", filename);
 	g_variant_builder_add(builder, "s", effect);
@@ -895,12 +901,6 @@ ags_window_load_add_menu_lv2(AgsWindow *window,
   }
 
   g_rec_mutex_unlock(lv2_manager_mutex);
-  
-  g_menu_item_set_submenu(lv2_item,
-			  G_MENU_MODEL(lv2_menu));  
-
-  g_menu_append_item(menu,
-		     lv2_item);
 }
 
 /**
@@ -933,10 +933,15 @@ ags_window_load_add_menu_vst3(AgsWindow *window,
   vst3_manager_mutex = AGS_VST3_MANAGER_GET_OBJ_MUTEX(vst3_manager);
 
   /* vst3 sub-menu */
-  vst3_menu = g_menu_new();
   vst3_item = g_menu_item_new("VST3",
 			      NULL);
+  g_menu_append_item(menu,
+		     vst3_item);
   
+  vst3_menu = g_menu_new();
+  g_menu_item_set_submenu(vst3_item,
+			  G_MENU_MODEL(vst3_menu));  
+
   /* get plugin */
   g_rec_mutex_lock(vst3_manager_mutex);
   
@@ -966,7 +971,7 @@ ags_window_load_add_menu_vst3(AgsWindow *window,
     item = g_menu_item_new(effect,
 			   "app.add_vst3_bridge");
 
-    builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+    builder = g_variant_builder_new(g_variant_type_new("as"));
     
     g_variant_builder_add(builder, "s", filename);
     g_variant_builder_add(builder, "s", effect);
@@ -984,12 +989,6 @@ ags_window_load_add_menu_vst3(AgsWindow *window,
     list = list->next;
   }
   
-  g_menu_item_set_submenu(vst3_item,
-			  G_MENU_MODEL(vst3_menu));  
-
-  g_menu_append_item(menu,
-		     vst3_item);
-
   g_list_free_full(start_list,
 		   (GDestroyNotify) g_object_unref);
 #endif
@@ -1015,9 +1014,14 @@ ags_window_load_add_menu_live_dssi(AgsWindow *window,
   dssi_manager_mutex = AGS_DSSI_MANAGER_GET_OBJ_MUTEX(dssi_manager);
 
   /* dssi sub-menu */
-  dssi_menu = g_menu_new();
   dssi_item = g_menu_item_new("live DSSI",
 			      NULL);
+  g_menu_append_item(menu,
+		     dssi_item);
+
+  dssi_menu = g_menu_new();
+  g_menu_item_set_submenu(dssi_item,
+			  G_MENU_MODEL(dssi_menu));  
 
   /* get plugin */
   g_rec_mutex_lock(dssi_manager_mutex);
@@ -1048,7 +1052,7 @@ ags_window_load_add_menu_live_dssi(AgsWindow *window,
     item = g_menu_item_new(effect,
 			   "app.add_live_dssi_bridge");
 
-    builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+    builder = g_variant_builder_new(g_variant_type_new("as"));
     
     g_variant_builder_add(builder, "s", filename);
     g_variant_builder_add(builder, "s", effect);
@@ -1066,12 +1070,6 @@ ags_window_load_add_menu_live_dssi(AgsWindow *window,
     list = list->next;
   }
 
-  g_menu_item_set_submenu(dssi_item,
-			  G_MENU_MODEL(dssi_menu));  
-
-  g_menu_append_item(menu,
-		     dssi_item);
-
   g_list_free_full(start_list,
 		   (GDestroyNotify) g_object_unref);
 }
@@ -1097,9 +1095,14 @@ ags_window_load_add_menu_live_lv2(AgsWindow *window,
   lv2_manager_mutex = AGS_LV2_MANAGER_GET_OBJ_MUTEX(lv2_manager);
 
   /* lv2 sub-menu */
-  lv2_menu = g_menu_new();
   lv2_item = g_menu_item_new("live LV2",
 			      NULL);
+  g_menu_append_item(menu,
+		     lv2_item);
+
+  lv2_menu = g_menu_new();
+  g_menu_item_set_submenu(lv2_item,
+			  G_MENU_MODEL(lv2_menu));  
 
   /* get plugin */
   g_rec_mutex_lock(lv2_manager_mutex);
@@ -1122,7 +1125,7 @@ ags_window_load_add_menu_live_lv2(AgsWindow *window,
 	item = g_menu_item_new(effect,
 			       "app.add_live_lv2_bridge");
 
-	builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+	builder = g_variant_builder_new(g_variant_type_new("as"));
     
 	g_variant_builder_add(builder, "s", filename);
 	g_variant_builder_add(builder, "s", effect);
@@ -1140,12 +1143,6 @@ ags_window_load_add_menu_live_lv2(AgsWindow *window,
   }
 
   g_rec_mutex_unlock(lv2_manager_mutex);
-  
-  g_menu_item_set_submenu(lv2_item,
-			  G_MENU_MODEL(lv2_menu));  
-
-  g_menu_append_item(menu,
-		     lv2_item);
 }
 
 void
@@ -1169,10 +1166,15 @@ ags_window_load_add_menu_live_vst3(AgsWindow *window,
   vst3_manager_mutex = AGS_VST3_MANAGER_GET_OBJ_MUTEX(vst3_manager);
 
   /* vst3 sub-menu */
-  vst3_menu = g_menu_new();
   vst3_item = g_menu_item_new("live VST3",
 			      NULL);
+  g_menu_append_item(menu,
+		     vst3_item);
   
+  vst3_menu = g_menu_new();
+  g_menu_item_set_submenu(vst3_item,
+			  G_MENU_MODEL(vst3_menu));  
+
   /* get plugin */
   g_rec_mutex_lock(vst3_manager_mutex);
   
@@ -1203,7 +1205,7 @@ ags_window_load_add_menu_live_vst3(AgsWindow *window,
       item = g_menu_item_new(effect,
 			     "app.add_live_vst3_bridge");
 
-      builder = g_variant_builder_new(G_VARIANT_TYPE("as"));
+      builder = g_variant_builder_new(g_variant_type_new("as"));
     
       g_variant_builder_add(builder, "s", filename);
       g_variant_builder_add(builder, "s", effect);
@@ -1221,12 +1223,6 @@ ags_window_load_add_menu_live_vst3(AgsWindow *window,
     /* iterate */
     list = list->next;
   }
-  
-  g_menu_item_set_submenu(vst3_item,
-			  G_MENU_MODEL(vst3_menu));  
-
-  g_menu_append_item(menu,
-		     vst3_item);
 
   g_list_free_full(start_list,
 		   (GDestroyNotify) g_object_unref);
